-- file: selectio_iserdes_8bit_ddr_diffin.vhd
-- (c) Copyright 2009 - 2011 Xilinx, Inc. All rights reserved.
-- 
-- This file contains confidential and proprietary information
-- of Xilinx, Inc. and is protected under U.S. and
-- international copyright and other intellectual property
-- laws.
-- 
-- DISCLAIMER
-- This disclaimer is not a license and does not grant any
-- rights to the materials distributed herewith. Except as
-- otherwise provided in a valid license issued to you by
-- Xilinx, and to the maximum extent permitted by applicable
-- law: (1) THESE MATERIALS ARE MADE AVAILABLE "AS IS" AND
-- WITH ALL FAULTS, AND XILINX HEREBY DISCLAIMS ALL WARRANTIES
-- AND CONDITIONS, EXPRESS, IMPLIED, OR STATUTORY, INCLUDING
-- BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, NON-
-- INFRINGEMENT, OR FITNESS FOR ANY PARTICULAR PURPOSE; and
-- (2) Xilinx shall not be liable (whether in contract or tort,
-- including negligence, or under any other theory of
-- liability) for any loss or damage of any kind or nature
-- related to, arising under or in connection with these
-- materials, including for any direct, or any indirect,
-- special, incidental, or consequential loss or damage
-- (including loss of data, profits, goodwill, or any type of
-- loss or damage suffered as a result of any action brought
-- by a third party) even if such damage or loss was
-- reasonably foreseeable or Xilinx had been advised of the
-- possibility of the same.
-- 
-- CRITICAL APPLICATIONS
-- Xilinx products are not designed or intended to be fail-
-- safe, or for use in any application requiring fail-safe
-- performance, such as life-support or safety devices or
-- systems, Class III medical devices, nuclear facilities,
-- applications related to the deployment of airbags, or any
-- other applications that could lead to death, personal
-- injury, or severe property or environmental damage
-- (individually and collectively, "Critical
-- Applications"). Customer assumes the sole risk and
-- liability of any use of Xilinx products in Critical
-- Applications, subject only to applicable laws and
-- regulations governing limitations on product liability.
-- 
-- THIS COPYRIGHT NOTICE AND DISCLAIMER MUST BE RETAINED AS
-- PART OF THIS FILE AT ALL TIMES.
------------------------------------------------------------------------------
-- User entered comments
------------------------------------------------------------------------------
-- None
------------------------------------------------------------------------------
--
-- EDIT: Only the clock generator buffers here


library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_misc.all;
use ieee.numeric_std.all;

library unisim;
use unisim.vcomponents.all;

entity iserdes_clock_generator is
port
 (
	-- Clock and reset signals
  CLK_IN_P                : in    std_logic;  -- Differential fast clock from IOB
  CLK_IN_N                : in    std_logic;
  CLK_OUT						      : out   std_logic;  -- Fast clock output (synchronous to data)
  CLK_DIV_OUT             : out   std_logic;  -- Slow clock output
  
  CLK_RESET               : in    std_logic); -- Reset signal for Clock circuit
  
end iserdes_clock_generator;

architecture sychro1 of iserdes_clock_generator is
  
  signal clk_in_int                : std_logic;
  
begin

  -- Create the clock logic
     ibufds_clk_inst : IBUFGDS
       generic map (
				 DIFF_TERM  => TRUE,
				 IOSTANDARD => "LVDS_25" )
       port map (
         I          => CLK_IN_P,
         IB         => CLK_IN_N,
         O          => clk_in_int);
         
-- High Speed BUFIO clock buffer
     bufio_inst : BUFIO
       port map (
         O => CLK_OUT,
         I => clk_in_int);
         
-- BUFR generates the slow clock
     clkout_buf_inst : BUFR
       generic map (
          SIM_DEVICE => "VIRTEX6",
          BUFR_DIVIDE => "4")
       port map (
          O           => CLK_DIV_OUT,
          CE          => '1',
          CLR         => CLK_RESET,
          I           => clk_in_int );

end sychro1;



